@@ -4,8 +4,6 @@ from cognite.air._admin_config import AdminAPI
 
 
 class SpacesAPI(AdminAPI):
-    _ENDPOINT = "/space"
-
     def create(self, id: str, name: str, description: str = ""):
         """Create a Space
 
@@ -16,13 +14,16 @@ class SpacesAPI(AdminAPI):
                 but has no functionality in the Front End yet)
 
         Examples:
-            >>> air_admin = AIRAdmin(client)
+            >>> from cognite.client import CogniteClient
+            >>> from cognite.air.admin import AIRAdmin
+            >>> c = CogniteClient()
+            >>> air_admin = AIRAdmin(c)
             >>> air_admin.spaces.create(id="my_space", name="My Space")
         """
         if not description:
             description = name
         payload = {"id": id, "name": name, "description": description, "groups": []}
-        self._post(payload)
+        self.air_client.post("/space", payload)
 
     def delete(self, id):
         """Not implemented yet. Please ask the AIR team which space to delete.
