@@ -1,3 +1,4 @@
+import copy
 from typing import Dict, List, Optional, Tuple, Union
 
 import numpy as np
@@ -203,6 +204,7 @@ class AlertCreator:
             int: Updated end when more events than max_events_to_be_processed. Use as new end.
 
         """
+        metadata = copy.deepcopy(metadata)
         self._validate_df(df)
         if isinstance(df, pd.DataFrame):
             possible_events = self._create_deviation_events_from_pandas(df)
@@ -270,6 +272,7 @@ class AlertCreator:
 
 
         """
+        metadata = copy.deepcopy(metadata)
         if metadata is None:
             metadata = {}
         self._validate_metadata(metadata)
